@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+
 import allure
 import pytest
 
@@ -8,6 +8,7 @@ import os
 import sys
 
 from selenium import webdriver
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 
 from widgetastic.browser import Browser
 
@@ -21,12 +22,21 @@ class CustomBrowser(Browser):
 
 
 @pytest.fixture(scope='session')
-def selenium(request):
-    options = webdriver.FirefoxOptions()
-    options.headless = True
-    driver = webdriver.Firefox(firefox_options=options)
+def browser_name():
+    return os.environ['BROWSER']
+
+
+@pytest.fixture(scope='session')
+def selenium(request, browser_name):
+    if browser_name == 'firefox':
+        driver = webdriver.Remote(desired_capabilities=DesiredCapabilities.FIREFOX)
+    elif browser_name == 'chrome':
+        caps = DesiredCapabilities.CHROME.copy()
+        caps['chromeOptions'] = {'args': ['disable-dev-shm-usage', 'no-sandbox']}
+        driver = webdriver.Remote(desired_capabilities=caps)
+    else:
+        sys.exit('Please provide BROWSER environment variable')
     request.addfinalizer(driver.quit)
-    driver.maximize_window()
     global selenium_browser
     selenium_browser = driver
     return driver
@@ -37,10 +47,11 @@ def browser(selenium, httpserver, request):
     this_module = sys.modules[__name__]
     path = os.path.dirname(this_module.__file__)
     testfilename = path + '/testing_page.html'
-    httpserver.serve_content(
+    server_root = '/'
+    httpserver.expect_request(server_root).respond_with_data(
         codecs.open(testfilename, mode='r', encoding='utf-8').read(),
         headers=[('Content-Type', 'text/html')])
-    selenium.get(httpserver.url)
+    selenium.get(httpserver.url_for(server_root))
     return CustomBrowser(selenium)
 
 
